==> docx4j-openxml-objects-8.0.0-sources.jar: org/docx4j/dml/STEffectContainerType.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_EffectContainerType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_EffectContainerType">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token">
 *     &lt;enumeration value="sib"/>
 *     &lt;enumeration value="tree"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_EffectContainerType")
@XmlEnum
public enum STEffectContainerType {


    /**
     * Sibling
     * 
     */
    @XmlEnumValue("sib")
    SIB("sib"),

    /**
     * Tree
     * 
     */
    @XmlEnumValue("tree")
    TREE("tree");
    private final String value;

    STEffectContainerType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STEffectContainerType fromValue(String v) {
        for (STEffectContainerType c: STEffectContainerType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> docx4j-openxml-objects-8.3.14-sources.jar: org/docx4j/dml/STEffectContainerType.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_EffectContainerType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_EffectContainerType"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="sib"/&gt;
 *     &lt;enumeration value="tree"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_EffectContainerType")
@XmlEnum
public enum STEffectContainerType {


    /**
     * Sibling
     * 
     */
    @XmlEnumValue("sib")
    SIB("sib"),

    /**
     * Tree
     * 
     */
    @XmlEnumValue("tree")
    TREE("tree");
    private final String value;

    STEffectContainerType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STEffectContainerType fromValue(String v) {
        for (STEffectContainerType c: STEffectContainerType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
